@@ -218,6 +218,9 @@ INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 # 验证码不正确。
 INVALIDPARAMETER_INVALIDVERIFYCODE = 'InvalidParameter.InvalidVerifyCode'
 
+# 缺少必填控件的值。
+INVALIDPARAMETER_MISSINGREQUIREDCOMPONENTVALUE = 'InvalidParameter.MissingRequiredComponentValue'
+
 # 不合法的手机号，请检查后重试。
 INVALIDPARAMETER_MOBILE = 'InvalidParameter.Mobile'
 
@@ -380,6 +383,9 @@ OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'
 # 禁止此项操作。
 OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 
+# 签署人年龄限制无法使用电子签服务。
+OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
+
 # 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
 OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'
 
@@ -413,6 +419,9 @@ OPERATIONDENIED_NOSUPPORTJUMPPAGE = 'OperationDenied.NoSupportJumpPage'
 # 未完成实名认证，请检查后重试。
 OPERATIONDENIED_NOVERIFY = 'OperationDenied.NoVerify'
 
+# 不属于企业超管或者法人。
+OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
+
 # 此社会信用编码未查询到结果，请检查后重试。
 OPERATIONDENIED_ORGUNIFORMSOCIALCREDITCODEERR = 'OperationDenied.OrgUniformSocialCreditCodeErr'
 
@@ -512,6 +521,9 @@ RESOURCENOTFOUND_SUPERADMIN = 'ResourceNotFound.SuperAdmin'
 # 模板不存在，请检查模板参数，模板配置，并稍后重试。
 RESOURCENOTFOUND_TEMPLATE = 'ResourceNotFound.Template'
 
+# Url不存在。
+RESOURCENOTFOUND_URL = 'ResourceNotFound.Url'
+
 # 用户或者员工信息不存在，请检查参数后重试。
 RESOURCENOTFOUND_USER = 'ResourceNotFound.User'
 
